const express = require('express')
const bodyParser = require('body-parser')
const cors = require('cors')
const passport = require('passport');
const mongoose = require('mongoose');

const dotenv = require('dotenv');
dotenv.config();

const db = process.env.mongoURI;

const auth = require('./routes/api/auth');
const users = require('./routes/api/users');
const clients = require('./routes/api/clients');
const cities = require('./routes/api/cities');
const invoices = require('./routes/api/invoices');
const lines = require('./routes/api/lines');

const app = express()
const apiPort = process.env.PORT || 5000;

app.use(bodyParser.urlencoded({ extended: true }))
app.use(cors())
app.use(bodyParser.json())

// connect to MongoDB
// db.on('error', console.error.bind(console, 'MongoDB connection error:'))
mongoose.connect(db, { useNewUrlParser: true, useUnifiedTopology: true })
  .then(() => console.log('MongoDB connected'))
  .catch(err => console.log(err));

// passport middleware
app.use(passport.initialize());
require('./config/passport')(passport);

// Routes
app.use('/api/auth', auth);
app.use('/api/users', users);
app.use('/api/clients', clients);
app.use('/api/cities', cities);
app.use('/api/invoices', invoices);
app.use('/api/lines', lines);

app.listen(apiPort, () => console.log(`Server running on port ${apiPort}`))