// calculates invoice's number from date and existing invoice numbers
const getInvoiceNumber = (date, invoices) => {
  const prefix = getDatePrefix(date);

  const currentInvoices = invoices
    .filter(invoice => getInvoicePrefix(invoice) === prefix)
    .map(invoice => invoice.number.substr(6, 2));

  const index = Math.max(0, ...currentInvoices) + 1;

  return prefix + index.toString().padStart(2, 0);
}

// returns a string containing the year and month of an invoice
const getInvoicePrefix = (invoice) => invoice.number.substr(0, 6);

// returns the year and month of a date either as a string or as a Date object 
const getDatePrefix = (date) => {
  if (typeof date === 'object') {
    const year = date.getFullYear();
    const month = date.getMonth() + 1;

    return year.toString() + month.toString().padStart(2, 0);
  } else {
    return date.substr(0, 4) + date.substr(5, 2);
  }
}

module.exports = {
  getInvoiceNumber,
  getInvoicePrefix,
  getDatePrefix
}