const Validator = require('validator');
const { COMMERCIAL_NAME_REQUIRED, INVALID_EMAIL, NIF_REQUIRED, ADDRESS_REQUIRED, CITY_REQUIRED, POSTAL_CODE_LENGTH, POSTAL_CODE_REQUIRED } = require('../constants/errors');
const { setError } = require('../lib/errors');
const isEmpty = require('./is-empty');

module.exports = function validateClientInput(data) {
  const errors = [];

  data.name = !isEmpty(data.name) ? data.name : '';
  data.surnames = !isEmpty(data.surnames) ? data.surnames : '';
  data.email = !isEmpty(data.email) ? data.email : '';
  data.commercialName = !isEmpty(data.commercialName) ? data.commercialName : '';
  data.phone = !isEmpty(data.phone) ? data.phone : '';
  data.nif = !isEmpty(data.nif) ? data.nif : '';
  data.address = !isEmpty(data.address) ? data.address : '';
  data.city = !isEmpty(data.city) ? data.city : '';
  data.postalcode = !isEmpty(data.postalcode) ? data.postalcode : '';
  data.acoount = !isEmpty(data.acoount) ? data.acoount : '';

  if (Validator.isEmpty(data.name) && Validator.isEmpty(data.commercialName)) {
    errors.push(setError(COMMERCIAL_NAME_REQUIRED));
  }

  if (!Validator.isEmpty(data.email) && !Validator.isEmail(data.email)) {
    errors.push(setError(INVALID_EMAIL));
  }

  if (Validator.isEmpty(data.nif)) {
    errors.push(setError(NIF_REQUIRED));
  }

  if (Validator.isEmpty(data.address)) {
    errors.push(setError(ADDRESS_REQUIRED));
  }

  if (Validator.isEmpty(data.city)) {
    errors.push(setError(CITY_REQUIRED));
  }

  if (!Validator.isLength(data.postalcode, { min: 5, max: 5 })) {
    errors.push(setError(POSTAL_CODE_LENGTH));
  }

  if (Validator.isEmpty(data.postalcode)) {
    errors.push(setError(POSTAL_CODE_REQUIRED));
  }

  return {
    errors,
    isValid: isEmpty(errors)
  }
}