const Validator = require('validator');
const { INVOICE_NAME_LENGTH, INVOICE_NAME_REQUIRED, INVOICE_RETENTION, INVOICE_RETENTION_REQUIRED, CLIENT_REQUIRED } = require('../constants/errors');
const { setError } = require('../lib/errors');
const isEmpty = require('./is-empty');

module.exports = function validateInvoiceInput(data) {
  const errors = [];

  data.name = !isEmpty(data.name) ? data.name : '';
  data.client = !isEmpty(data.client) ? data.client : '';
  data.ret = !isEmpty(data.ret) ? data.ret.toString() : '';

  if (!Validator.isLength(data.name, { min: 2, max: 50 })) {
    errors.push(setError(INVOICE_NAME_LENGTH));
  }

  if (Validator.isEmpty(data.name)) {
    errors.push(setError(INVOICE_NAME_REQUIRED));
  }

  if (parseInt(data.ret) === NaN || parseInt(data.ret).toString() !== data.ret) {
    errors.push(setError(INVOICE_RETENTION));
  }

  if (Validator.isEmpty(data.ret)) {
    errors.push(setError(INVOICE_RETENTION_REQUIRED));
  }

  if (Validator.isEmpty(data.client)) {
    errors.push(setError(CLIENT_REQUIRED));
  }

  return {
    errors,
    isValid: isEmpty(errors)
  }
}