const Validator = require('validator');
const { LINE_CONCEPT_LENGTH, LINE_CONCEPT_REQUIRED, LINE_QUANTITY, LINE_AMOUNT, LINE_VAT } = require('../constants/errors');
const { setError } = require('../lib/errors');
const isEmpty = require('./is-empty');

module.exports = function validateCityInput(data) {
  const errors = [];

  data.concept = !isEmpty(data.concept) ? data.concept : '';

  if (!Validator.isLength(data.concept, { min: 2, max: 100 })) {
    errors.push(setError(LINE_CONCEPT_LENGTH));
  }

  if (Validator.isEmpty(data.concept)) {
    errors.push(setError(LINE_CONCEPT_REQUIRED));
  }

  if (parseFloat(data.quantity) === NaN) {
    errors.push(setError(LINE_QUANTITY));
  }

  if (parseFloat(data.amount) === NaN) {
    errors.push(setError(LINE_AMOUNT));
  }

  if (parseInt(data.vat) === NaN) {
    errors.push(setError(LINE_VAT));
  }

  return {
    errors,
    isValid: isEmpty(errors)
  }
}