const Validator = require('validator');
const { USER_NAME_LENGTH, NAME_REQUIRED, SURNAMES_REQUIRED, PHONE_REQUIRED, NIF_REQUIRED, ADDRESS_REQUIRED, CITY_REQUIRED, POSTAL_CODE_LENGTH, POSTAL_CODE_REQUIRED } = require('../constants/errors');
const { setError } = require('../lib/errors');
const isEmpty = require('./is-empty');

module.exports = function validateProfileInput(data) {
  const errors = [];

  data.name = !isEmpty(data.name) ? data.name : '';
  data.surnames = !isEmpty(data.surnames) ? data.surnames : '';
  data.phone = !isEmpty(data.phone) ? data.phone : '';
  data.nif = !isEmpty(data.nif) ? data.nif : '';
  data.address = !isEmpty(data.address) ? data.address : '';
  data.city = !isEmpty(data.city) ? data.city : '';
  data.postalcode = !isEmpty(data.postalcode) ? data.postalcode : '';

  if (!Validator.isLength(data.name, { min: 2, max: 30 })) {
    errors.push(setError(USER_NAME_LENGTH));
  }

  if (Validator.isEmpty(data.name)) {
    errors.push(setError(NAME_REQUIRED));
  }

  if (Validator.isEmpty(data.surnames)) {
    errors.push(setError(SURNAMES_REQUIRED));
  }

  if (Validator.isEmpty(data.phone)) {
    errors.push(setError(PHONE_REQUIRED));
  }

  if (Validator.isEmpty(data.nif)) {
    errors.push(setError(NIF_REQUIRED));
  }

  if (Validator.isEmpty(data.address)) {
    errors.push(setError(ADDRESS_REQUIRED));
  }

  if (Validator.isEmpty(data.city)) {
    errors.push(setError(CITY_REQUIRED));
  }

  if (!Validator.isLength(data.postalcode, { min: 5, max: 5 })) {
    errors.push(setError(POSTAL_CODE_LENGTH));
  }

  if (Validator.isEmpty(data.postalcode)) {
    errors.push(setError(POSTAL_CODE_REQUIRED));
  }

  return {
    errors,
    isValid: isEmpty(errors)
  }
}