const Validator = require('validator');
const { PASSWORD_REQUIRED, PASSWORD_LENGTH, PASSWORD_CONFIRMATION_REQUIRED, MATCH_PASSWORDS, INVALID_EMAIL, EMAIL_REQUIRED } = require('../constants/errors');
const { setError } = require('../lib/errors');
const isEmmpty = require('./is-empty');

const validateRecoveryPasswordInput = (data) => {
  const errors = [];

  data.password = !isEmmpty(data.password) ? data.password : '';
  data.password2 = !isEmmpty(data.password2) ? data.password2 : '';

  if (Validator.isEmpty(data.password)) {
    errors.push(setError(PASSWORD_REQUIRED));
  }

  if (!Validator.isLength(data.password, { min: 6, max: 30 })) {
    errors.push(setError(PASSWORD_LENGTH));
  }

  if (Validator.isEmpty(data.password2)) {
    errors.push(setError(PASSWORD_CONFIRMATION_REQUIRED));
  }

  if (!Validator.equals(data.password, data.password2)) {
    errors.push(setError(MATCH_PASSWORDS));
  }

  return {
    errors,
    isValid: isEmmpty(errors)
  }
}

const validateRecoveryEmailInput = (data) => {
  const errors = [];

  data.email = !isEmmpty(data.email) ? data.email : '';

  if (!Validator.isEmail(data.email)) {
    errors.push(setError(INVALID_EMAIL));
  }

  if (Validator.isEmpty(data.email)) {
    errors.push(setError(EMAIL_REQUIRED));
  }

  return {
    errors,
    isValid: isEmmpty(errors)
  }
}

module.exports = {
  validateRecoveryPasswordInput,
  validateRecoveryEmailInput
}