const Validator = require('validator');
const {POSTAL_CODE_REQUIRED, POSTAL_CODE_LENGTH, CITY_REQUIRED, ADDRESS_REQUIRED, NIF_REQUIRED, NAME_LENGTH, NAME_REQUIRED, SURNAMES_REQUIRED, EMAIL_REQUIRED, INVALID_EMAIL, PASSWORD_REQUIRED, PASSWORD_LENGTH, PASSWORD_CONFIRMATION_REQUIRED, MATCH_PASSWORDS, PHONE_REQUIRED } = require('../constants/errors');
const { setError } = require('../lib/errors');
const isEmpty = require('./is-empty');

module.exports = function validateRegisterInput(data) {
  const errors = [];

  data.name = !isEmpty(data.name) ? data.name : '';
  data.surnames = !isEmpty(data.surnames) ? data.surnames : '';
  data.email = !isEmpty(data.email) ? data.email : '';
  data.password = !isEmpty(data.password) ? data.password : '';
  data.password2 = !isEmpty(data.password2) ? data.password2 : '';
  data.phone = !isEmpty(data.phone) ? data.phone : '';
  data.nif = !isEmpty(data.nif) ? data.nif : '';
  data.address = !isEmpty(data.address) ? data.address : '';
  data.city = !isEmpty(data.city) ? data.city : '';
  data.postalcode = !isEmpty(data.postalcode) ? data.postalcode : '';

  if (!Validator.isLength(data.name, { min: 2, max: 30 })) {
    errors.push(setError(NAME_LENGTH));
  }

  if (Validator.isEmpty(data.name)) {
    errors.push(setError(NAME_REQUIRED));
  }

  if (Validator.isEmpty(data.surnames)) {
    errors.push(setError(SURNAMES_REQUIRED));
  }

  if (Validator.isEmpty(data.email)) {
    errors.push(setError(EMAIL_REQUIRED));
  }

  if (!Validator.isEmail(data.email)) {
    errors.push(setError(INVALID_EMAIL));
  }

  if (Validator.isEmpty(data.password)) {
    errors.push(setError(PASSWORD_REQUIRED));
  }

  if (!Validator.isLength(data.password, { min: 6, max: 30 })) {
    errors.push(setError(PASSWORD_LENGTH));
  }

  if (Validator.isEmpty(data.password2)) {
    errors.push(setError(PASSWORD_CONFIRMATION_REQUIRED));
  }

  if (!Validator.equals(data.password, data.password2)) {
    errors.push(setError(MATCH_PASSWORDS));
  }

  if (Validator.isEmpty(data.phone)) {
    errors.push(setError(PHONE_REQUIRED));
  }

  if (Validator.isEmpty(data.nif)) {
    errors.push(setError(NIF_REQUIRED));
  }

  if (Validator.isEmpty(data.address)) {
    errors.push(setError(ADDRESS_REQUIRED));
  }

  if (Validator.isEmpty(data.city)) {
    errors.push(setError(CITY_REQUIRED));
  }

  if (!Validator.isLength(data.postalcode, { min: 5, max: 5 })) {
    errors.push(setError(POSTAL_CODE_LENGTH));
  }

  if (Validator.isEmpty(data.postalcode)) {
    errors.push(setError(POSTAL_CODE_REQUIRED));
  }

  return {
    errors,
    isValid: isEmpty(errors)
  }
}